@@ -1,6 +1,6 @@
 #############################################################################
 #
-# Copyright (c) 2008 Zope Corporation and Contributors.
+# Copyright (c) 2008 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -26,9 +26,6 @@ from five.grok.components import EditForm, DisplayForm
 from five.grok.components import View, ViewletManager
 from five.grok.formlib import AutoFields
 
-# backwards compatibility. Probably not needed by many, but just in case.
-# please start using grokcore.view.View again.
-CodeView = View
 
 # Override the one from grokcore.view so that we get Zope 2 semantics
 from five.grok.components import ZopeTwoPageTemplate as PageTemplate
