@@ -1,6 +1,6 @@
 #############################################################################
 #
-# Copyright (c) 2008 Zope Corporation and Contributors.
+# Copyright (c) 2008 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,28 +12,21 @@
 #
 ##############################################################################
 
-import martian
-import five.grok
-import grokcore.security
-import grokcore.view
-import grokcore.component
-import grokcore.site.interfaces
-
-from zope import interface, component
-from zope.app.container.interfaces import INameChooser
-from zope.publisher.interfaces.browser import IDefaultBrowserLayer
 from five.grok import components, formlib
 from grokcore.view.meta.directoryresource import _get_resource_path
-from martian.error import GrokError
+from zope import interface, component
+from zope.publisher.interfaces.browser import IDefaultBrowserLayer
+import five.grok
+import grokcore.component
+import grokcore.security
+import grokcore.view
+import martian
 
-from Products.Five.security import protectClass, protectName
+from AccessControl.security import protectClass, protectName
 from App.class_init import InitializeClass as initializeClass
 
-import os.path
-
 
 class FormGrokker(martian.ClassGrokker):
-
     martian.component(components.GrokForm)
     martian.directive(grokcore.component.context)
     martian.priority(800)       # Must be run before real formlib grokker.
@@ -104,23 +97,6 @@ class DirectoryResourceGrokker(martian.ClassGrokker):
         return _register_resource(config, resource_path, name, layer)
 
 
-class StaticResourcesGrokker(martian.GlobalGrokker):
-
-    def grok(self, name, module, module_info, config, **kw):
-        # we're only interested in static resources if this module
-        # happens to be a package
-        if not module_info.isPackage():
-            return False
-        resource_path = _get_resource_path(module_info, 'static')
-
-        if not os.path.exists(resource_path):
-            return False
-
-        name = module_info.dotted_name
-        layer = IDefaultBrowserLayer
-        return _register_resource(config, resource_path, name, layer)
-
-
 class ViewletSecurityGrokker(martian.ClassGrokker):
     martian.component(five.grok.Viewlet)
     martian.directive(grokcore.security.require, name='permission')
