@@ -1,6 +1,8 @@
-"""Testing that grokcore adapters work under Zope2
+"""
+Testing that grokcore adapters work under Zope2:
 
-  >>> grok.testing.grok(__name__)
+  >>> from five.grok.tests.adapters import *
+  >>> grok.testing.grok('five.grok.tests.adapters')
 
   >>> from OFS.SimpleItem import SimpleItem
   >>> item = SimpleItem()
@@ -10,17 +12,21 @@
   True
   >>> IId.providedBy(adapted)
   True
-  
+
   >>> adapted.id()
   'item'
 
+  >>> a = A()
+  >>> IB(a)
+  'adapted to IB'
+
 """
 from zope.interface import Interface
 from five import grok
 from OFS.interfaces import ISimpleItem
 
 class IId(Interface):
-    
+
     def id():
         """Returns the ID of the object"""
 
@@ -30,3 +36,14 @@ class SimpleItemIdAdapter(grok.Adapter):
 
     def id(self):
         return self.context.getId()
+
+class A(object):
+    pass
+
+class IB(Interface):
+    pass
+
+@grok.adapter(A)
+@grok.implementer(IB)
+def atob(context):
+    return 'adapted to IB'
